pub struct BaselineSummary {
pub id: String,
pub benchmark: String,
pub version: String,
pub created_at: DateTime<Utc>,
pub git_ref: Option<String>,
pub git_sha: Option<String>,
pub tags: Vec<String>,
pub receipt: Option<RunReceipt>,
}Expand description
Summary of a baseline record (without full receipt).
Fields
id: Stringbenchmark: Stringversion: Stringcreated_at: DateTime<Utc>git_ref: Option<String>git_sha: Option<String>receipt: Option<RunReceipt>Trait Implementations
Sourceimpl Clone for BaselineSummary
impl Clone for BaselineSummary
Sourcefn clone(&self) -> BaselineSummary
fn clone(&self) -> BaselineSummary
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BaselineSummary
impl Debug for BaselineSummary
Sourceimpl<'de> Deserialize<'de> for BaselineSummary
impl<'de> Deserialize<'de> for BaselineSummary
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<BaselineSummary, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<BaselineSummary, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<BaselineRecord> for BaselineSummary
impl From<BaselineRecord> for BaselineSummary
Sourcefn from(record: BaselineRecord) -> BaselineSummary
fn from(record: BaselineRecord) -> BaselineSummary
Converts to this type from the input type.
Sourceimpl JsonSchema for BaselineSummary
impl JsonSchema for BaselineSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BaselineSummary
impl PartialEq for BaselineSummary
Sourceimpl Serialize for BaselineSummary
impl Serialize for BaselineSummary
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for BaselineSummary