pub struct HealthResponse {
pub status: String,
pub version: String,
pub storage: StorageHealth,
}Expand description
Response for health check.
Fields
status: Stringversion: Stringstorage: StorageHealthTrait Implementations
Sourceimpl Clone for HealthResponse
impl Clone for HealthResponse
Sourcefn clone(&self) -> HealthResponse
fn clone(&self) -> HealthResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HealthResponse
impl Debug for HealthResponse
Sourceimpl<'de> Deserialize<'de> for HealthResponse
impl<'de> Deserialize<'de> for HealthResponse
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<HealthResponse, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<HealthResponse, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for HealthResponse
impl JsonSchema for HealthResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for HealthResponse
impl Serialize for HealthResponse
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more