pub struct ListDecisionsResponse {
pub decisions: Vec<DecisionRecord>,
pub pagination: PaginationInfo,
}Expand description
Response for decision list operation.
Fields
decisions: Vec<DecisionRecord>pagination: PaginationInfoTrait Implementations
Sourceimpl Clone for ListDecisionsResponse
impl Clone for ListDecisionsResponse
Sourcefn clone(&self) -> ListDecisionsResponse
fn clone(&self) -> ListDecisionsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListDecisionsResponse
impl Debug for ListDecisionsResponse
Sourceimpl<'de> Deserialize<'de> for ListDecisionsResponse
impl<'de> Deserialize<'de> for ListDecisionsResponse
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ListDecisionsResponse, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ListDecisionsResponse, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ListDecisionsResponse
impl JsonSchema for ListDecisionsResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for ListDecisionsResponse
impl Serialize for ListDecisionsResponse
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more