pub struct PromoteBaselineRequest {
pub from_version: String,
pub to_version: String,
pub git_ref: Option<String>,
pub git_sha: Option<String>,
pub tags: Vec<String>,
pub normalize: bool,
}Expand description
Request for baseline promotion.
Fields
from_version: Stringto_version: Stringgit_ref: Option<String>git_sha: Option<String>normalize: boolTrait Implementations
Sourceimpl Clone for PromoteBaselineRequest
impl Clone for PromoteBaselineRequest
Sourcefn clone(&self) -> PromoteBaselineRequest
fn clone(&self) -> PromoteBaselineRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PromoteBaselineRequest
impl Debug for PromoteBaselineRequest
Sourceimpl<'de> Deserialize<'de> for PromoteBaselineRequest
impl<'de> Deserialize<'de> for PromoteBaselineRequest
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<PromoteBaselineRequest, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<PromoteBaselineRequest, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PromoteBaselineRequest
impl JsonSchema for PromoteBaselineRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for PromoteBaselineRequest
impl Serialize for PromoteBaselineRequest
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more