pub struct StorageHealth {
pub backend: String,
pub status: String,
}Expand description
Health status of a storage backend.
Fields
backend: Stringstatus: StringTrait Implementations
Sourceimpl Clone for StorageHealth
impl Clone for StorageHealth
Sourcefn clone(&self) -> StorageHealth
fn clone(&self) -> StorageHealth
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StorageHealth
impl Debug for StorageHealth
Sourceimpl<'de> Deserialize<'de> for StorageHealth
impl<'de> Deserialize<'de> for StorageHealth
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<StorageHealth, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<StorageHealth, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StorageHealth
impl JsonSchema for StorageHealth
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for StorageHealth
impl PartialEq for StorageHealth
Sourceimpl Serialize for StorageHealth
impl Serialize for StorageHealth
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for StorageHealth
impl StructuralPartialEq for StorageHealth