pub struct SubmitVerdictRequest {
pub benchmark: String,
pub run_id: String,
pub status: VerdictStatus,
pub counts: VerdictCounts,
pub reasons: Vec<String>,
pub git_ref: Option<String>,
pub git_sha: Option<String>,
}Expand description
Request for submitting a verdict.
Fields
benchmark: Stringrun_id: Stringstatus: VerdictStatuscounts: VerdictCountsreasons: Vec<String>git_ref: Option<String>git_sha: Option<String>Trait Implementations
Sourceimpl Clone for SubmitVerdictRequest
impl Clone for SubmitVerdictRequest
Sourcefn clone(&self) -> SubmitVerdictRequest
fn clone(&self) -> SubmitVerdictRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SubmitVerdictRequest
impl Debug for SubmitVerdictRequest
Sourceimpl<'de> Deserialize<'de> for SubmitVerdictRequest
impl<'de> Deserialize<'de> for SubmitVerdictRequest
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<SubmitVerdictRequest, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<SubmitVerdictRequest, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SubmitVerdictRequest
impl JsonSchema for SubmitVerdictRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for SubmitVerdictRequest
impl Serialize for SubmitVerdictRequest
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more