pub struct UploadBaselineResponse {
pub id: String,
pub benchmark: String,
pub version: String,
pub created_at: DateTime<Utc>,
pub etag: String,
}Expand description
Response for successful baseline upload.
Fields
id: Stringbenchmark: Stringversion: Stringcreated_at: DateTime<Utc>etag: StringTrait Implementations
Sourceimpl Clone for UploadBaselineResponse
impl Clone for UploadBaselineResponse
Sourcefn clone(&self) -> UploadBaselineResponse
fn clone(&self) -> UploadBaselineResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UploadBaselineResponse
impl Debug for UploadBaselineResponse
Sourceimpl<'de> Deserialize<'de> for UploadBaselineResponse
impl<'de> Deserialize<'de> for UploadBaselineResponse
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<UploadBaselineResponse, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<UploadBaselineResponse, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for UploadBaselineResponse
impl JsonSchema for UploadBaselineResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for UploadBaselineResponse
impl Serialize for UploadBaselineResponse
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more