pub struct SqliteKeyStore { /* private fields */ }Expand description
SQLite-backed persistent key store.
Implementations
Sourceimpl SqliteKeyStore
impl SqliteKeyStore
Sourcepub fn new(conn: Arc<Mutex<Connection>>) -> Result<Self, StoreError>
pub fn new(conn: Arc<Mutex<Connection>>) -> Result<Self, StoreError>
Opens or creates a key store backed by the given SQLite connection.
The api_keys table is created if it does not exist.
Sourcepub fn in_memory() -> Result<Self, StoreError>
pub fn in_memory() -> Result<Self, StoreError>
Creates an in-memory SQLite key store (for testing).